@@ -75,6 +75,8 @@ CAS.checksum <- function(CAS.string)
 #' @param allow.na If TRUE (default is FALSE) then NA values are written to the
 #' table, otherwise they are ignored.
 #'
+#' @param suppress.messages Whether or not the output messages are suppressed.
+#'
 #' @return \item{data.frame}{A new data.frame containing the data in
 #' current.table augmented by new.table} 
 #' @author John Wambaugh
@@ -89,7 +91,8 @@ augment.table <- function(
   overwrite=FALSE,
   sig.fig = 4,
   clint.pvalue.overwrite=TRUE,
-  allow.na=FALSE)
+  allow.na=FALSE,
+  suppress.messages=FALSE)
 {
   # Columns stored in chem.phys_and_invitro.table:
   CHEM.ID.COLS<-c(
@@ -304,7 +307,8 @@ augment.table <- function(
     } else if (!is.na(this.table[index,this.property]) | 
       !overwrite)
     {
-      warning(paste("Preexisting value found for",
+      if (!suppress.messages) 
+        warning(paste("Preexisting value found for",
                     this.CAS,
                     "property",
                     this.property,
@@ -374,6 +378,8 @@ augment.table <- function(
 #' @param allow.na If TRUE (default is FALSE) then NA values are written to the
 #' table, otherwise they are ignored.
 #'
+#' @param suppress.messages Whether or not the output messages are suppressed.
+#' 
 #' @return \item{data.frame}{A new data.frame containing the data in
 #' current.table augmented by new.table} 
 #' @author John Wambaugh
@@ -500,7 +506,8 @@ add_chemtable <- function(
   overwrite=FALSE,
   sig.fig = 4,
   clint.pvalue.overwrite=TRUE,
-  allow.na=FALSE)
+  allow.na=FALSE,
+  suppress.messages=FALSE)
 {
 # Trouble with tibls:
   new.table <- as.data.frame(new.table)
@@ -579,7 +586,8 @@ columns in \"data.list\".")
         overwrite=overwrite,
         sig.fig=sig.fig,
         clint.pvalue.overwrite=clint.pvalue.overwrite,
-        allow.na=allow.na)
+        allow.na=allow.na,
+        suppress.messages=suppress.messages)
     }
   }
 
