@@ -199,7 +199,7 @@ convert_units <- function(input.units = NULL,
   }
   
   # How many unit conversions do we currently have:
-  NUM.CONVERSIONS <- 60
+  NUM.CONVERSIONS <- 65
   
   known_input_units <- vector(mode = "character", length = NUM.CONVERSIONS)
   known_output_units <- vector(mode = "character", length = NUM.CONVERSIONS)
@@ -292,6 +292,10 @@ convert_units <- function(input.units = NULL,
     known_output_units[17] <- 'um'
     known_conversions[17] <- 1/10^3
     
+    known_input_units[62] <- 'mol'
+    known_output_units[62] <- 'umol'
+    known_conversions[62] <- 10^6
+    
     known_input_units[18] <- 'nmol/l'
     known_output_units[18] <- 'nm'
     known_conversions[18] <- 1
@@ -466,6 +470,7 @@ convert_units <- function(input.units = NULL,
     known_output_units[55] <- 'ppmv'
     known_conversions[55] <- 1.225/(this.MW/volidealgas * 10^6)
     
+    # general unit conversions (weight, volume, surface area)
     known_input_units[56] <- 'g'
     known_output_units[56] <- 'mg'
     known_conversions[56] <- 1000
@@ -485,6 +490,25 @@ convert_units <- function(input.units = NULL,
     known_input_units[60] <- 'm3'
     known_output_units[60] <- 'l'
     known_conversions[60] <- 1e3
+    
+    known_input_units[61] <- 'mg'
+    known_output_units[61] <- 'kg'
+    known_conversions[61] <- 1e-6
+    
+    #62 is in an earlier section 
+    
+    known_input_units[63] <- 'g'
+    known_output_units[63] <- 'kg'
+    known_conversions[63] <- 1e-3
+    
+    known_input_units[64] <- 'ul'
+    known_output_units[64] <- 'm3' #cubic meters
+    known_conversions[64] <- 1e-9
+    
+    known_input_units[65] <- 'mm2' #millimeters squared
+    known_output_units[65] <- 'm2' #meters squared
+    known_conversions[65] <- 1e-6
+    
         
     #Use these vectors to construct a matrix of conversion factors:
     #rows are input units, columns are output units
