@@ -467,10 +467,11 @@ get_cheminfo <- function(info="CAS",
   
   # Pare the chemical data down to only those chemicals where all the necessary
   # parameters are not NA
-    good.chemicals.index <- apply(
-      chem.physical_and_invitro.data[,necessary.params],
-      1,
-      function(x) all(!is.na(x)))
+    good.chemicals.index <- setNames(
+      stats::complete.cases(chem.physical_and_invitro.data[necessary.params]),
+      rownames(chem.physical_and_invitro.data)
+    )	
+    
   # print a warning of exclusion criteria for compounds
   #  - ONLY if it is applies (i.e. is an exclusion criterion for at least 1 compound)
   if (!suppress.messages & any(good.chemicals.index==FALSE))
