@@ -134,3 +134,9 @@ void root1comp (int *neq, double *t, double *y, int *ng, double *gout, double *o
 {
 
 } /* root */
+
+/*----- Forcing functions (NOT USED WITH THIS MODEL) */
+void initforc1comp (void (* odeforcs)(int *, double *))
+{
+
+}
