@@ -9,8 +9,6 @@ library(httk)
 #   to precision differences.
 signif(head(solve_dermal_pbtk(chem.name="propylparaben")), 
        2)
-signif(head(solve_dermal_pbtk(chem.cas="94-13-3")), 
-       2)
 
 p <- parameterize_dermal_pbtk(chem.name="propylparaben")
 p <- p[sort(names(p))]
@@ -18,7 +16,5 @@ p <- p[sort(names(p))]
 for (this.param in 
      names(p)[order(toupper(names(p)))]) cat(
      paste(this.param,": ",p[[this.param]],"\r\n",sep=""))
-signif(head(solve_dermal_pbtk(parameters=p)),
-       2)
 
 quit("no")
\ No newline at end of file
